@@ -32,18 +32,21 @@ $this->messages=array
    "update"=>"Update",
    "delete"=>"Delete",
    "clear_cache"=>"Clear cache",
+   "renum"=>"Renum",
    "all_in_one"=>"All in one page",
    "no_title"=>"No title",
    "doc_created"=>"Document created",
    "doc_updated"=>"Document updated",
    "doc_deleted"=>"Document deleted",
    "cache_cleared"=>"Cache cleared",
+   "renum_done"=>"Renum done",
    "confirm_delete"=>"Are you sure you want to delete this document?",
    "image_created"=>"Image created",
    "image_updated"=>"Image updated",
    "image_deleted"=>"Image deleted",
    "confirm_delete_image"=>"Are you sure you want to delete this image?",
    "confirm_clear_cache"=>"Are you sure you want to clear the cache?",
+   "confirm_renum"=>"Are you sure you want to perform a renum?",
    "confirm_all_in_one"=>"Are you sure you want to display all contents on one single page? This can take a lot of time...",
    "title_403"=>"403 Forbidden",
    "title_404"=>"404 Not found",
@@ -54,6 +57,8 @@ $this->messages=array
    "title_imagecreateform"=>"New image",
    "title_clearcacheform"=>"Clear cache",
    "title_clearcache"=>"Clear cache",
+   "title_renumform"=>"Renum",
+   "title_renum"=>"Renum",
    "title_allinoneform"=>"All in one page",
    "title_about"=>"About UWiKiCMS",
    "status"=>"Status",
@@ -84,6 +89,7 @@ $this->messages=array
    "action_new"=>"New page",
    "action_imagenew"=>"New image",
    "action_clearcache"=>"Clear cache",
+   "action_renum"=>"Renum",
    "action_help"=>"Help",
    "action_allinone"=>"All in one page",
    "action_gallery"=>"Gallery (Mozilla/Firefox)",
