@@ -32,18 +32,21 @@ $this->messages=array
    "update"=>"Modifier",
    "delete"=>"Supprimer",
    "clear_cache"=>"Vider le cache",
+   "renum"=>"Renum&eacute;rotation",
    "all_in_one"=>"Tout sur une page",
    "no_title"=>"Sans titre",
    "doc_created"=>"Document cr&eacute;&eacute;",
    "doc_updated"=>"Document mis &agrave; jour",
    "doc_deleted"=>"Document supprim&eacute;",
    "cache_cleared"=>"Cache vid&eacute;",
+   "renum_done"=>"Renum&eacute;rotation termin&eacute;e",
    "confirm_delete"=>"&Ecirc;tes vous s&ucirc;r de vouloir supprimer ce document?",
    "image_created"=>"Image cr&eacute;&eacute;e",
    "image_updated"=>"Image mise &agrave; jour",
    "image_deleted"=>"Image supprim&eacute;e",
    "confirm_delete_image"=>"&Ecirc;tes vous s&ucirc;r de vouloir supprimer cette image?",   
    "confirm_clear_cache"=>"&Ecirc;tes vous s&ucirc;r de vouloir vider le cache?",
+   "confirm_renum"=>"&Ecirc;tes vous s&ucirc;r de vouloir renum&eacute;roter?",
    "confirm_all_in_one"=>"&Ecirc;tes vous s&ucirc;r de vouloir tout afficher sur une seule page? Cela peut prendre beaucoup de temps...",
    "title_403"=>"403 Interdit",
    "title_404"=>"404 Non trouv&eacute;",
@@ -54,6 +57,8 @@ $this->messages=array
    "title_imagecreateform"=>"Nouvelle image",
    "title_clearcacheform"=>"Vider le cache",
    "title_clearcache"=>"Vider le cache",
+   "title_renumform"=>"Renum&eacute;roter",
+   "title_renum"=>"Renum&eacute;roter",
    "title_allinoneform"=>"Tout sur une page",
    "title_about"=>"&Agrave; propos d'UWiKiCMS",
    "status"=>"&Eacute;tat",
@@ -84,6 +89,7 @@ $this->messages=array
    "action_new"=>"Nouvelle page",
    "action_imagenew"=>"Nouvelle image",
    "action_clearcache"=>"Vider le cache",
+   "action_renum"=>"Renum&eacute;roter",
    "action_help"=>"Aide",
    "action_allinone"=>"Tout sur une page",
    "action_gallery"=>"Diaporama (Mozilla/Firefox)",
